pub struct NoopProgress;Trait Implementations
Sourceimpl ProgressReporter for NoopProgress
impl ProgressReporter for NoopProgress
fn update(&self, _: &str, _: Option<u64>, _: Option<u64>)
fn finish(&self, _: &str)
Sourcefn pause(&self) -> Box<dyn PauseGuard + '_>
fn pause(&self) -> Box<dyn PauseGuard + '_>
Hide our own spinner/bars while a child process draws to the terminal.
Implementations should clear their lines until the returned guard is dropped.
The default is a no-op for reporters that don’t draw to a TTY.