OciRef

Struct OciRef 

pub struct OciRef {
    pub registry: String,
    pub repository: String,
    pub tag: Option<String>,
    pub digest: Option<String>,
}

Fields

registry: Stringrepository: Stringtag: Option<String>digest: Option<String>

Implementations

Source

impl OciRef

pub fn parse(s: &str) -> Result<Self, String>

pub fn docker_arg(&self) -> String

Return the string Docker expects for docker pull / docker run. For docker.io images the registry prefix is stripped so that Docker Hub resolves references correctly across all Docker versions.